
# Slot: slot with space 1




URI: [ks:classWithSpaces__slot_with_space_1](https://w3id.org/linkml/tests/kitchen_sink/classWithSpaces__slot_with_space_1)


## Domain and Range

None &#8594;  <sub>0..1</sub> [String](String.md)

## Parents


## Children


## Used by

 * [ClassWithSpaces](ClassWithSpaces.md)
 * [SubclassTest](SubclassTest.md)
